[cig-commits] r18827 - in seismo/3D/ADJOINT_TOMO/measure_adj: . PLOTS scripts_tomo

carltape at geodynamics.org carltape at geodynamics.org
Fri Aug 12 16:45:20 PDT 2011


Author: carltape
Date: 2011-08-12 16:45:19 -0700 (Fri, 12 Aug 2011)
New Revision: 18827

Modified:
   seismo/3D/ADJOINT_TOMO/measure_adj/Makefile
   seismo/3D/ADJOINT_TOMO/measure_adj/Makefile_ifort_caltech
   seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats.pl
   seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats_all.pl
   seismo/3D/ADJOINT_TOMO/measure_adj/README
   seismo/3D/ADJOINT_TOMO/measure_adj/ma_constants.f90
   seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub.f90
   seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub2.f90
   seismo/3D/ADJOINT_TOMO/measure_adj/ma_variables.f90
   seismo/3D/ADJOINT_TOMO/measure_adj/measure_adj.f90
   seismo/3D/ADJOINT_TOMO/measure_adj/rotate_adj_src.f90
   seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/prepare_measure_adj.pl
   seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_measure_adj.pl
   seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_mt_cc_plot.pl
   seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_tomo.pl
   seismo/3D/ADJOINT_TOMO/measure_adj/write_par_file.pl
Log:
changed "mt" (multitaper) tags to "ma" (measurement + adjoint); in some cases, "mt" was deleted


Modified: seismo/3D/ADJOINT_TOMO/measure_adj/Makefile
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/Makefile	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/Makefile	2011-08-12 23:45:19 UTC (rev 18827)
@@ -14,20 +14,20 @@
 
 
 # NOTE: order matters if modules depend on other modules
-MOD = mt_constants mt_variables ascii_rw mt_sub2 mt_sub
+MOD = ma_constants ma_variables ascii_rw ma_sub2 ma_sub
 
 SRC_DIR = .
 MOD_DIR = mod
 OBJ_DIR = obj
 BIN_DIR = .
-MAIN = mt_measure_adj rotate_adj_src
+MAIN = measure_adj rotate_adj_src
 MOD_FLAG = module
 
 MOD_OBJ = $(patsubst %,$(OBJ_DIR)/%.o,$(MOD))
 F90_OBJ = #$(patsubst %,$(OBJ_DIR)/%.o,$(SUB))
 OBJ = $(F90_OBJ) $(MOD_OBJ)
 
-all : mt_measure_adj rotate_adj_src
+all : measure_adj rotate_adj_src
 
 $(MAIN) : % : $(SRC_DIR)/%.f90 $(F90_OBJ) $(MOD_OBJ)
 	$(F90) -o $(BIN_DIR)/$* $(F90_FLAGS) $(SRC_DIR)/$*.f90 -I$(MOD_DIR) -J$(MOD_DIR) $(OBJ) -L${SACLIBDIR} $(LIB)
@@ -44,6 +44,6 @@
 .PHONY : clean
 
 clean:
-	\rm -f *.o *.mod $(OBJ_DIR)/*.o $(MOD_DIR)/*.mod  *.txt* STA.*  OUTPUT_FILES/*  *.sac rotate_adj_src mt_measure_adj
+	\rm -f *.o *.mod $(OBJ_DIR)/*.o $(MOD_DIR)/*.mod  *.txt* STA.*  OUTPUT_FILES/*  *.sac rotate_adj_src measure_adj
 
 

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/Makefile_ifort_caltech
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/Makefile_ifort_caltech	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/Makefile_ifort_caltech	2011-08-12 23:45:19 UTC (rev 18827)
@@ -4,20 +4,20 @@
 
 LIB = -L/opt/seismo-util/lib -lDRWFiles -lf90recipes -lDSacio -lDSacLib -lSacTools -lm
 
-MOD = mt_constants mt_variables mt_sub2 mt_sub
+MOD = ma_constants ma_variables ma_sub2 ma_sub
 
 SRC_DIR = .
 MOD_DIR = mod
 OBJ_DIR = obj
 BIN_DIR = .
-MAIN = mt_measure_adj
+MAIN = measure_adj
 MOD_FLAG = module
 
 MOD_OBJ = $(patsubst %,$(OBJ_DIR)/%.o,$(MOD))
 F90_OBJ = #$(patsubst %,$(OBJ_DIR)/%.o,$(SUB))
 OBJ = $(F90_OBJ) $(MOD_OBJ)
 
-all : mt_measure_adj rotate_adj_src
+all : measure_adj rotate_adj_src
 
 $(MAIN) : % : $(SRC_DIR)/%.f90 $(F90_OBJ) $(MOD_OBJ)
 	$(F90) -o $(BIN_DIR)/$* $(F90_FLAGS) $(SRC_DIR)/$*.f90 -$(MOD_FLAG) $(MOD_DIR) $(OBJ) $(LIB)
@@ -34,6 +34,6 @@
 .PHONY : clean
 
 clean:
-	\rm -f *.o *.mod *~ $(OBJ_DIR)/*.o $(MOD_DIR)/*.mod  *.txt* STA.*  OUTPUT_FILES/*  *.sac rotate_adj_src mt_measure_adj
+	\rm -f *.o *.mod *~ $(OBJ_DIR)/*.o $(MOD_DIR)/*.mod  *.txt* STA.*  OUTPUT_FILES/*  *.sac rotate_adj_src measure_adj
 
 

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats.pl
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -112,7 +112,7 @@
 #`awk '{print \$21}' $meas_file > $file4`; ($min4,$max4) = split(" ",`minmax -C $file4`); $st4 = sprintf("min/max = %.2f / %.2f",$min4,$max4);
 
 # create a new measurement file for plotting the histograms
-$file0 = "${eid}_cc_dT_dA_dTsigma_dAsigma";    # see mt_measure_adj.f90
+$file0 = "${eid}_cc_dT_dA_dTsigma_dAsigma";    # see measure_adj.f90
 
 # KEY: extract columns from window_chi file
 #`awk '{print \$15,\$16,\$20,\$21,\$15/\$20,\$16/\$21}' $meas_file > $file0`;

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats_all.pl
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats_all.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/PLOTS/plot_win_stats_all.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -81,7 +81,7 @@
   print "\n------------------------------";
   print "\n $i, $eid \n";
 
-  # name of file containing measurements (see mt_sub.f90)
+  # name of file containing measurements (see ma_sub.f90)
   $dir_meas = "${dir_run}/${eid}/${smodel}/MEASURE_${Ttag}";
   $meas_file = "${dir_meas}/${ftag}_window_chi";
   if (-f $meas_file) {

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/README
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/README	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/README	2011-08-12 23:45:19 UTC (rev 18827)
@@ -16,8 +16,8 @@
    > cp PLOTS/9818433_T006_T030_MPM_CI_m16_iker07_win_adj_DEFAULT.pdf .
    > make clean
    > make
-   > mt_measure_adj
-   > csh -f run_mt_measure_adj.csh
+   > measure_adj
+   > csh -f run_measure_adj.csh
 If all goes well, you should produce the figure
    PLOTS/9818433_T006_T030_MPM_CI_m16_iker07_win_adj.pdf
 to match 9818433_T006_T030_MPM_CI_m16_iker07_win_adj_DEFAULT.pdf
@@ -82,10 +82,10 @@
 
 These scripts have been placed in the directory scripts_tomo:
 
-prepare_mt_measure_adj.pl -- prepares the directory for running the measurement code WITH PLOTS
-run_mt_measure_adj.pl     -- runs the code and makes output plots
+prepare_measure_adj.pl -- prepares the directory for running the measurement code WITH PLOTS
+run_measure_adj.pl     -- runs the code and makes output plots
 run_mt_cc_plot.pl         -- runs the code in cross-correlation mode AND multi-taper mode for plots
-run_tomo.pl               -- master script that calls prepare_mt_measure_adj.pl and run_mt_measure_adj.pl
+run_tomo.pl               -- master script that calls prepare_measure_adj.pl and run_measure_adj.pl
 combine_2_adj_src.pl      -- combines two sets of adjoint sources and creates a new STATIONS_ADJOINT file
 combine_2_adj_src_all.pl  -- calls combine_2_adj_src.pl repeatedly to make the final set of adjoint sources
 

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/ma_constants.f90
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/ma_constants.f90	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/ma_constants.f90	2011-08-12 23:45:19 UTC (rev 18827)
@@ -1,4 +1,4 @@
-module mt_constants
+module ma_constants
 
   ! number of entries in window_chi output file
   integer, parameter :: N_MEASUREMENT = 5
@@ -33,4 +33,4 @@
   ! constructs adjoint sources for a "ray density" kernel, where all misfits are equal to one
   logical:: DO_RAY_DENSITY_SOURCE = .false.
   
-end module mt_constants
+end module ma_constants

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub.f90
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub.f90	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub.f90	2011-08-12 23:45:19 UTC (rev 18827)
@@ -1,8 +1,8 @@
-module mt_sub
+module ma_sub
 
-  use mt_constants
-  use mt_variables
-  use mt_sub2
+  use ma_constants
+  use ma_variables
+  use ma_sub2
   use ascii_rw
 
   implicit none
@@ -2079,4 +2079,4 @@
 
   end subroutine get_sacfile_header
 
-end module mt_sub
+end module ma_sub

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub2.f90
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub2.f90	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/ma_sub2.f90	2011-08-12 23:45:19 UTC (rev 18827)
@@ -1,7 +1,6 @@
-module mt_sub2
+module ma_sub2
  
-
-  use mt_constants 
+  use ma_constants 
   
   implicit none
 
@@ -653,5 +652,4 @@
       return
       end subroutine boxcar
 
-
-end module mt_sub2
+end module ma_sub2

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/ma_variables.f90
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/ma_variables.f90	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/ma_variables.f90	2011-08-12 23:45:19 UTC (rev 18827)
@@ -1,6 +1,6 @@
-module mt_variables
+module ma_variables
 
-  use mt_constants
+  use ma_constants
 !
 ! multi-taper measurements
 !
@@ -10,7 +10,7 @@
 ! For synthetic data, we can use a lower NPI.
 ! number of tapers should be fixed as twice NPI -- see Latex notes
 !
-! See write_par_file.pl and mt_measure_adj.f90
+! See write_par_file.pl and measure_adj.f90
 
   character(len=150) :: OUT_DIR
 
@@ -25,10 +25,10 @@
 
   logical :: DISPLAY_DETAILS,OUTPUT_MEASUREMENT_FILES,RUN_BANDPASS,COMPUTE_ADJOINT_SOURCE
 
-end module mt_variables
+end module ma_variables
 
 
-module mt_weighting
+module ma_weighting
 
 ! module for weighting/normalizing measurements
 
@@ -53,4 +53,4 @@
   integer, parameter :: Rayleigh_R = 5
   integer, parameter :: Love_T = 6
 
-end module mt_weighting
+end module ma_weighting

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/measure_adj.f90
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/measure_adj.f90	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/measure_adj.f90	2011-08-12 23:45:19 UTC (rev 18827)
@@ -1,7 +1,7 @@
-program mt_measure_adj
+program measure_adj
 
-  !  main program that calls the subroutines to make the MT measurements
-  !  and compute the corresponding adjoint sources
+  !  main program that calls the subroutines to make measurements within input time windows
+  !  and then compute the corresponding adjoint sources
 
   ! input parameter:
   !  1. imeas = 1, normalized waveform difference. Adjoint source is constructed from the data
@@ -21,12 +21,12 @@
   !  8. imeas = 8, multitaper ampltidue difference for an event kernel. The measurement between
   !                       data and synthetics is used in constructing the adjoint source. See multitaper_notes.pdf.
 
-  use mt_variables
-  use mt_constants
+  use ma_variables
+  use ma_constants
   use ascii_rw       ! dwascii()
-  use mt_sub2        ! fft(), fftinv()
-  use mt_sub         ! mt_measure(), mt_adj()
-  use mt_weighting 
+  use ma_sub2        ! fft(), fftinv()
+  use ma_sub         ! mt_measure(), mt_adj()
+  use ma_weighting 
 
   implicit none
 
@@ -36,7 +36,6 @@
   double precision :: t01, dt1, t02, dt2, t0, dt, tstart, tend, tt, dtt, df
   double precision, dimension(NCHI) :: window_chi
   double precision :: fend0, fstart0, fend, fstart
-  !double precision :: TSHORT, TLONG   ! mtm_variables.f90
 
   ! sac header information
   integer :: yr,jda,ho,mi
@@ -58,8 +57,8 @@
 
   !********* PROGRAM STARTS HERE *********************
 
-  ! read in MEASUREMENT.PAR (see mt_sub.f90 and write_par_file.pl)
-  ! most variables are global (see mt_variables.f90)
+  ! read in MEASUREMENT.PAR (see ma_sub.f90 and write_par_file.pl)
+  ! most variables are global (see ma_variables.f90)
   call read_par_file(fstart0,fend0,tt,dtt,nn,chan)
 
   ! uses weights to balance love and rayleigh measurements
@@ -450,17 +449,17 @@
   close(12)  ! write: window_index
   close(13)  ! write: window_chi
 
-end program mt_measure_adj
+end program measure_adj
 
 subroutine setup_weighting(chan_syn)
   !
   ! determines weights based on number of window picks on radial, transverse and vertical components
   !
-  use mt_weighting
+  use ma_weighting
 
-  use mt_constants,only: NDIM
-  use mt_sub,only: get_sacfile_header,drsac1
-  use mt_sub2,only: TOL
+  use ma_constants,only: NDIM
+  use ma_sub,only: get_sacfile_header,drsac1
+  use ma_sub2,only: TOL
 
   implicit none
   character(len=10) :: chan_syn
@@ -662,4 +661,4 @@
     print*
   endif
 
-end subroutine
+end subroutine setup_weighting

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/rotate_adj_src.f90
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/rotate_adj_src.f90	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/rotate_adj_src.f90	2011-08-12 23:45:19 UTC (rev 18827)
@@ -10,7 +10,7 @@
   integer :: nptst, nptsr, npts
   logical :: r_exist, t_exist, z_exist
   double precision :: t0t,dtt,t0r,dtr, t0,dt, costh, sinth
-  integer, parameter :: NDIM = 40000  ! check mt_constants.f90
+  integer, parameter :: NDIM = 40000  ! check ma_constants.f90
   double precision, dimension(NDIM) :: rdata, tdata, edata, ndata
   
   call getarg(1,bazch)

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/prepare_measure_adj.pl
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/prepare_measure_adj.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/prepare_measure_adj.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -2,7 +2,7 @@
 
 #==========================================================
 #
-#  prepare_mt_measure_adj.pl
+#  prepare_measure_adj.pl
 #  Carl Tape
 #  19-Oct-2009
 #
@@ -16,11 +16,11 @@
 #    Tmin/Tmax      bandpass periods for filtering data and synthetics
 #
 #  EXAMPLE:
-#    prepare_mt_measure_adj.pl m16 0 1 0 6/30 9818433
+#    prepare_measure_adj.pl m16 0 1 0 6/30 9818433
 #
 #==========================================================
 
-if (@ARGV < 6) {die("Usage: prepare_mt_measure_adj.pl smodel itest iplot iwindow Tmin/Tmax eid\n");}
+if (@ARGV < 6) {die("Usage: prepare_measure_adj.pl smodel itest iplot iwindow Tmin/Tmax eid\n");}
 ($smodel,$itest,$iplot,$iwindow,$Ts,$eid) = @ARGV;
 
 # iwindow: controls where the data, synthetics, and windows files are
@@ -88,7 +88,7 @@
 
 #=============================================
 # write the C-shell script to file
-$cshfile = "prepare_mt_measure_adj.csh";
+$cshfile = "prepare_measure_adj.csh";
 print "\nWriting to $cshfile ...\n";
 open(CSH,">$cshfile");
 

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_measure_adj.pl
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_mt_cc_plot.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_mt_cc_plot.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -67,7 +67,7 @@
 open(CSH,">$cshfile");
 
 # empty the output files directory and compile the measurement code
-# (this is done in prepare_mt_measure_adj.pl)
+# (this is done in prepare_measure_adj.pl)
 #print CSH "\\rm -rf OUTPUT_FILES ; mkdir OUTPUT_FILES ; make clean\n make\n";
 
 # create MEASUREMENT.PAR file
@@ -78,7 +78,7 @@
 #---------------------------------------------
 
 # run the measurement code
-print CSH "mt_measure_adj\n";
+print CSH "measure_adj\n";
 
 # copy adjoint sources into PLOTS
 print CSH "\\rm -rf ${plot_adj_dir}\n mkdir ${plot_adj_dir}\n";
@@ -108,7 +108,7 @@
 
 # run the measurement code and save output file
 # (re-compilation is not necessary)
-print CSH "mt_measure_adj > run_file\n";
+print CSH "measure_adj > run_file\n";
 print CSH "cp OUTPUT_FILES/*adj ${plot_adj_dir}\n";
 
 # create adjoint sources and STATIONS_ADJOINT file for SPECFEM3D

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_tomo.pl
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/write_par_file.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/write_par_file.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -4,7 +4,7 @@
 #  write_par_file.pl
 #
 #  This script writes a parameters file to be used in the measurement code.
-#  See the reading-in of this file in mt_measure_adj.f90.
+#  See the reading-in of this file in measure_adj.f90.
 #
 #  INPUT:
 #     tstart/dt/ntime



More information about the CIG-COMMITS mailing list
--- seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_measure_adj.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_measure_adj.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -2,12 +2,12 @@
 
 #==========================================================
 #
-#  run_mt_measure_adj.pl
+#  run_measure_adj.pl
 #  Carl Tape
 #  19-Oct-2009
 #
 #  This script runs following prepare_mt_measure.pl.
 #  It executes mt_measure_adj and then ouputs a complete set of
 #  un-rotated adjoint sources for SPECFEM3D as well as STATIONS_ADJOINT.
 #  It also provides the option of making a set of plots by
 #  calling plot_win_adj_all.pl.
@@ -21,11 +21,11 @@
 #     ...              see write_par_file.pl
 #
 #  EXAMPLE (T = [6s, 30s]):
-#     run_mt_measure_adj.pl m16 -10/200 0 1 0 -0.585/0.011/18200 7 BH 6/30 0/1/1/1 -5.0/5.0/-1.5/1.5/0.7 1/1.0/0.5 1/0.02/2.5/2.0/2.5/3.5/1.5
+#     run_measure_adj.pl m16 -10/200 0 1 0 -0.585/0.011/18200 7 BH 6/30 0/1/1/1 -5.0/5.0/-1.5/1.5/0.7 1/1.0/0.5 1/0.02/2.5/2.0/2.5/3.5/1.5
 #
 #==========================================================
 
-if (@ARGV < 13) {die("Usage: run_mt_measure_adj.pl xxx\n")}
+if (@ARGV < 13) {die("Usage: run_measure_adj.pl xxx\n")}
 ($smodel,$lcut,$itest,$iplot,$iboth,$tvec,$imeas,$chan,$Ts,$iparbools,$par1,$par2,$par3) = @ARGV;
 
 $pwd = $ENV{PWD};
@@ -41,7 +41,7 @@
 $stafile1 = "STATIONS_TOMO";
 $stafile2 = "STATIONS_ADJOINT";
 
-# a CMTSOLUTION file should have been copied here from prepare_mt_measure_adj.pl
+# a CMTSOLUTION file should have been copied here from prepare_measure_adj.pl
 $cmtfile = glob("CMTSOLUTION_*");
 
 print "\n-- $cmtfile --\n";
@@ -55,12 +55,12 @@
 
 #=============================================
 # write the C-shell script to file
-$cshfile = "run_mt_measure_adj.csh";
+$cshfile = "run_measure_adj.csh";
 print "\nWriting to $cshfile ...\n";
 open(CSH,">$cshfile");
 
 # empty the output files directory and compile the measurement code
-# (this is done in prepare_mt_measure_adj.pl)
+# (this is done in prepare_measure_adj.pl)
 #print CSH "\\rm -rf OUTPUT_FILES ; mkdir OUTPUT_FILES ; make clean\n make\n";
 
 #----------------------------
@@ -101,8 +101,8 @@
 #---------------------------------------------
 
 # run the measurement code
-print CSH "mt_measure_adj > run_file\n";    # output to file
-#print CSH "mt_measure_adj\n";
+print CSH "measure_adj > run_file\n";    # output to file
+#print CSH "measure_adj\n";
 
 if ($iplot == 1) {
   # copy adjoint sources into PLOTS
@@ -2,12 +2,12 @@
 #  19-Oct-2009
 #
-#  This script runs following prepare_mt_measure.pl.
-#  It executes mt_measure_adj and then ouputs a complete set of
+#  This script runs following prepare_measure.pl.
+#  It executes measure_adj and then ouputs a complete set of
 #  un-rotated adjoint sources for SPECFEM3D as well as STATIONS_ADJOINT.
 #  It also provides the option of making a set of plots by

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_mt_cc_plot.pl
===================================================================
--- seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_tomo.pl	2011-08-12 23:26:38 UTC (rev 18826)
+++ seismo/3D/ADJOINT_TOMO/measure_adj/scripts_tomo/run_tomo.pl	2011-08-12 23:45:19 UTC (rev 18827)
@@ -9,7 +9,7 @@
 #  This is the master program for running the measurement code on all the
 #  events for which the windowing code has been run.
 #
 #  NOTE: The command run_mt_measure_adj.pl below contains additional input parameters.
 #
 #  EXAMPLES (19-Oct-2009):
 #    run_tomo.pl m16 0.011 1.0 5 BH 6/30 0/1/1/0 -5.0/5.0/-1.5/1.5/0.7 1/1.0/0.5 3/0.02/2.5/2.0/2.5/3.5/1.5  # CC: no adjoint source
@@ -157,7 +157,7 @@
 
        # this also compiles the measurement code, which is not needed for each new event
        print "--> run the measurement code and make adjoint sources\n";
-       print CSH "prepare_mt_measure_adj.pl $smodel 0 1 0 $Ts $eid\n";
+       print CSH "prepare_measure_adj.pl $smodel 0 1 0 $Ts $eid\n";
 
        #------------------------------------
 
@@ -165,7 +165,7 @@
        $iplot = 1;
        $iboth = 0;
 
-       print CSH "run_mt_measure_adj.pl $smodel $lcut $itest $iplot $iboth $tvec $imeas $chan $Ts $iparbools $par1 $par2 $par3\n";
+       print CSH "run_measure_adj.pl $smodel $lcut $itest $iplot $iboth $tvec $imeas $chan $Ts $iparbools $par1 $par2 $par3\n";
 
        #print CSH "run_mt_cc_plot.pl $smodel $lcut $itest $tvec $imeas $chan $Ts $iparbools $par1 $par2 $par3\n";
 
@@ -9,7 +9,7 @@
 #  events for which the windowing code has been run.
 #
-#  NOTE: The command run_mt_measure_adj.pl below contains additional input parameters.
+#  NOTE: The command run_measure_adj.pl below contains additional input parameters.
 #
 #  EXAMPLES (19-Oct-2009):

Modified: seismo/3D/ADJOINT_TOMO/measure_adj/write_par_file.pl
===================================================================